@@ -1,4 +1,5 @@
 test_that("get_data returns a data frame", {
+  skip_on_cran()
 
   key <- "ICP.M.DE.N.000000+XEF000.4.ANR"
   filter <- list(lastNObservations = 12)
@@ -9,10 +10,13 @@ test_that("get_data returns a data frame", {
 })
 
 test_that("get_dataflows returns a data frame", {
+  skip_on_cran()
   expect_equal(class(get_dataflows()), c("tbl_df", "tbl", "data.frame"))
 })
 
 test_that("get_dimensions returns a list of data frames", {
+  skip_on_cran()
+
   dims <- get_dimensions("ICP.M.DE.N.000000+XEF000.4.ANR")
   expect_equal(class(dims), "list")
 
@@ -21,6 +25,8 @@ test_that("get_dimensions returns a list of data frames", {
 })
 
 test_that("malformed series key returns 404 error", {
+  skip_on_cran()
+
   key <- "ICP.M.DE.N.000000+XEF000.4.ANRs"
   expect_error(get_data(key), regexp = "404")
   expect_error(get_dimensions(key), regexp = "404")
@@ -28,10 +34,25 @@ test_that("malformed series key returns 404 error", {
 })
 
 test_that("get_description returns a character vector", {
-  key <- "STS.A.AT+DE.N.UNEH.RTT000.4.AV3"
+  skip_on_cran()
+
+  key <- "LFSI.M..S.UNEHRT.TOTAL0.15_74.T"
   desc <- get_description(key)
   expect_true(is.character(desc))
 
   desc_lengths <- vapply(desc, nchar, numeric(1))
   expect_true(all(desc > 0))
 })
+
+test_that("quarterly date conversion works", {
+  skip_on_cran()
+
+  key <- "MNA.Q.Y.DE.W2.S1.S1.B.B1GQ._Z._Z._Z.EUR.LR.N"
+  gdp <- get_data(key)
+  gdp_dates <- convert_dates(gdp$obstime)
+  expect_is(gdp_dates, "Date")
+  # correct format
+  expect_false(anyNA(as.Date(as.character(gdp_dates), format = "%Y-%m-%d")))
+  # end of quarter
+  expect_true(all(grepl(pattern = "-(30|31)", gdp_dates)))
+})
